@@ -1,6 +1,6 @@
 from arinrest.common.connection import ArinRestConnection
 from arinrest.rpki.rpki import Rpki
-from arinrest.irr.route import Route
+from arinrest.irr import IRRClient
 from arinrest.rdap import RdapClient
 from typing import Union
 
@@ -22,9 +22,8 @@ class ArinRest(object):
     def irr(self, **kwargs):
         dev = kwargs.get("dev", False)
 
-        self.connection = ArinRestConnection("irr", self.api_key, dev=dev)
-        self.route = Route(self.connection)
-        return self
+        connection = ArinRestConnection("irr", self.api_key, dev=dev)
+        return IRRClient(connection)
 
     def rdap(self, **kwargs):
         connection = ArinRestConnection("rdap", None)
